/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-01-19 15:17+0100\nLast-Translator: Cornelius Weiß <c.weiss@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 2.0.6\n"

, "Import CSV formated contacts from Google address book"
: "Importiere CSV formatierte Kontakte aus einem Google Adressbuch"

, "Contact import from Google address book"
: "Kontaktimport aus dem Google-Adressbuch"

, "LX-Office CSV Contact import"
: "LX-Office CSV Kontakt Import"

, "Import CSV formated contacts from LX-Office"
: "Importiere CSV formatierte Kontakte von LX-Office"

, "Tine 2.0 contact CSV import"
: "Tine 2.0 Kontakt CSV Import"

, "Import CSV formated contacts from Tine 2.0 address book"
: "Importiere CSV formatierte Kontakte aus einem Tine 2.0 Adressbuch"

, "Import list (###CURRENTDATE###)"
: "Importliste (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Kontakte importiert am ###CURRENTDATE### um ###CURRENTTIME### von ###USERFULLNAME###"

, "Import vCard formated contacts"
: "Importiere vCard formatierte Kontakte"

, "Contact VCARD import"
: "VCARD-Import für Kontakte"

, "Import CSV formated contacts from Exchange / Outlook address book"
: "Importiere CSV formatierte Kontakte aus einem Exchange / Outlook Adressbuch"

, "Contact CSV import from Outlook address book"
: "CSV-Kontaktimport aus dem Outlook-Adressbuch"

, "Contact CSV import from mac address book"
: "CSV-Kontaktimport aus dem Mac-Adressbuch"

, "Import CSV formated contacts from Outlook 2007 German address book"
: "Importiere CSV formatierte Kontakte aus einem Outlook 2007 Deutsch Adressbuch"

, "Import CSV formated contacts from Outlook 2010 German address book"
: "Importiere CSV formatierte Kontakte aus einem Outlook 2010 Deutsch Adressbuch"

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 Deutsch"

, "CSV Outlook 2010 German"
: "CSV Outlook 2010 Deutsch"

, "It is not allowed to delete a contact linked to an user account!"
: "Es ist nicht erlaubt, einen Kontakt zu Löschen, der zu einem Benutzerkonto gehört"

, "This Short Name already exists. How about {0}?"
: "Dieses Kürzel existiert bereits. Wie wäre es mit {0}?"

, "It is not allowed to add non-account contacts to this list"
: "Es ist nicht erlaubt, Nichtbenutzer zu dieser Liste hinzuzufügen"

, "E-Mail address is already given. Please choose another one."
: "Die E-Mail-Adresse ist bereits vergeben. Bitte wählen Sie eine andere."

, "Excel overview"
: "Excel - Übersicht"

, "Word details"
: "Word - Details"

, "Excel all data"
: "Excel - Alle Daten"

, "CSV all data"
: "CSV - Alle Daten"

, "OpenDocument all data"
: "OpenDocument - Alle Daten"

, "Relations"
: "Verknüpfungen"

, "PDF details"
: "PDF - Details"

, "Word letter"
: "Word - Brief"

, "Excel phone list"
: "Excel - Telefonliste"

, "Excel phone list grouped by company"
: "Excel - Telefonliste, gruppiert nach Firma"

, "Business Contact Data"
: "Geschäftliche Kontaktdaten"

, "Organisation / Unit"
: "Firma / Abteilung"

, "Business Address"
: "Geschäftliche Anschrift"

, "Email"
: "E-Mail"

, "Telephone Work"
: "Telefon (Büro)"

, "Telephone Cellphone"
: "Telefon (Mobil)"

, "Telephone Car"
: "Telefon (Auto)"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: "Pager"

, "URL"
: "URL"

, "Role"
: "Funktion"

, "Room"
: "Raum"

, "Assistant"
: "Assistent"

, "Assistant Telephone"
: "Telefon des Assistenten"

, "Private Contact Data"
: "Private Kontaktdaten"

, "Private Address"
: "Private Anschrift"

, "Email Home"
: "E-Mail  (Zuhause)"

, "Telephone Home"
: "Telefon  (Zuhause)"

, "Telephone Cellphone Private"
: "Telefon (Mobil)"

, "Telephone Fax Home"
: "Fax (Zuhause)"

, "URL Home"
: "URL (Zuhause)"

, "Other Data"
: "Andere Daten"

, "Birthday"
: "Geburtstag"

, "Job Title"
: "Berufs-Bezeichnung"

, "Enabled Features"
: "Feature aktivieren"

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: "Adressbuch Listenansicht"

, "Shows an additional view for lists inside the addressbook"
: "Zeigt eine zusätzliche Ansicht für Gruppen im Adressbuch"

, "Addressbook Industries"
: "Adressbuch Branchen"

, "Add Industry field to Adressbook"
: "Fügte das Feld Branchen zum Adressbuch hinzu"

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: "Ressourcen im Adressbuch verwalten"

, "Show the resources grid also inside the Addressbook"
: "Die Ressourcen Liste auch im Adressbuch anzeigen"

, "Show Structure Panel in Addressbook"
: "Strukturen Modul im Adressbuch anzeigen "

, "Visualize relations of records"
: "Visualisierung von Beziehungen von Einträgen"

, "Contact duplicate check fields"
: "Kontaktfelder für den Dublettencheck"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Diese Felder werden überprüft, wenn ein neuer Kontakt erstellt wird. Falls ein Eintrag mit den gleichen Daten in diesen Feldern angelegt wird, wird eine Fehlermeldung angezeit, auf die der Benutzer reagieren kann."

, "Contact Hidden Criteria"
: "Kriterium zum ausblenden von Kontakten"

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: "Der Kontakt wird ausgeblendet wenn er ... ist. (eines von: deaktiviert, abgelaufen oder niemals)"

, "Contact salutations available"
: "Verfügbare Kontaktanreden"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Mögliche Kontaktanreden. Bitte beachten Sie, dass sich zusätzliche Werte beim Export oder der Synchronisation auf andere Systeme auswirken."

, "Mr"
: "Herr"

, "Ms"
: "Frau"

, "Company"
: "Firma"

, "Parsing rules for addresses"
: "Analyseregeln für Adressen"

, "Path to a XML file with address parsing rules."
: "Pfad zu einer XML-Datei mit den Analyseregeln für Adressen."

, "List types available"
: "Verfügbare Listen Typen"

, "List types available."
: "Verfügbare Listen Typen."

, "Department"
: "Abteilung"

, "Mailing list"
: "E-Mail-Verteiler"

, "Use Nominatim during contact import"
: "Nutzung der Nominatim API während des Kontakt Imports"

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: "Synchronisations Backends"

, "Default telephone country code"
: ""

, "Addressbook, Addressbooks"
: [
  "Adressbuch"
 ,"Adressbücher"

]
, "Contact, Contacts"
: [
  "Kontakt"
 ,"Kontakte"

]
, "Show Disabled"
: "Zeige geschlossene"

, "Path"
: "Pfad"

, "List Member"
: "Gruppenmitglied"

, "List Role Member"
: "Gruppenfunktion"

, "Telephone"
: "Telefon"

, "Telephone Normalized"
: "Telefon normalisiert"

, "Country"
: "Land"

, "City"
: "Ort"

, "Postalcode"
: "Postleitzahl"

, "Region"
: "Bundesland"

, "Street"
: "Straße"

, "Street 2"
: "Straße 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Land (privat)"

, "City (private)"
: "Stadt (privat)"

, "Postalcode (private)"
: "Postleitzahl (privat)"

, "Region (private)"
: "Bundesland (privat)"

, "Street (private)"
: "Straße (privat)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "E-Mail (privat)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geografischer Ort"

, "Groups"
: "Gruppen"

, "Industry, Industries"
: [
  "Branche"
 ,"Branchen"

]
, "Note"
: "Notizen"

, "Last Name"
: "Nachname"

, "Display Name"
: "Angezeigter Name"

, "Full Name"
: "Vollständiger Name"

, "First Name"
: "Vorname"

, "Middle Name"
: "zweiter Vorname"

, "Title"
: "Titel"

, "Suffix"
: "Namenszusatz"

, "Short Name"
: "Kürzel"

, "Unit"
: "Abteilung"

, "Paths"
: "Pfade"

, "Preferred Address"
: "Bevorzugte Adresse"

, "Job Role"
: "Funktion"

, "Salutation"
: "Anrede"

, "syncBackendIds"
: ""

, "Car phone"
: "Auto-Telefon"

, "Mobile"
: "Handy"

, "Mobile (private)"
: "Handy (privat)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (privat)"

, "Phone (private)"
: "Telefon (privat)"

, "Pager"
: "Pager"

, "Phone"
: "Telefon"

, "Type"
: "Typ"

, "Timezone"
: "Zeitzone"

, "Web"
: "Internet"

, "URL (private)"
: "Webseite (privat)"

, "Label"
: ""

, "List, Lists"
: [
  "Gruppe"
 ,"Gruppen"

]
, "Percent"
: "Prozent"

, "Description"
: "Beschreibung"

, "Members"
: "Mitglieder"

, "E-Mail"
: "E-Mail"

, "List type"
: "Listen Typ"

, "All contacts I have read grants for"
: "Alle Kontakte für die ich Lese-Rechte habe"

, "My company"
: "Meine Firma"

, "All coworkers in my company"
: "Alle Mitarbeiter meiner Firma"

, "My contacts"
: "Meine Kontakte"

, "All contacts in my Addressbooks"
: "Alle Kontakte in meinen Adressbüchern"

, "Last modified by me"
: "Zuletzt von mir bearbeitet"

, "All contacts that I have last modified"
: "Alle Kontakte, die ich zuletzt bearbeitet habe"

, "Internal Contacts"
: "Interne Kontakte"

, "manage shared addressbooks"
: "Gemeinsame Adressbücher verwalten"

, "Create new shared addressbook folders"
: "Neue gemeinsame Adressbücher anlegen"

, "manage shared addressbook favorites"
: "Gemeinsame Adressbuch-Favoriten verwalten"

, "Create or update shared addressbook favorites"
: "Gemeinsame Adressbuch-Favoriten erstellen oder bearbeiten"

, "Manage lists in CoreData"
: "Verwalte Listen in den Stammdaten"

, "View, create, delete or update lists in CoreData application"
: "Gruppen in den Stammdaten sehen, anlegen, löschen oder bearbeiten"

, "Manage list functions in CoreData"
: "Verwalte Gruppenfunktionen in den Stammdaten"

, "View, create, delete or update list functions in CoreData application"
: "Gruppenfunktionen in den Stammdaten ansehen, anlegen, löschen oder bearbeiten"

, "Manage list email options"
: "E-Mail Optionen von Listen verwalten"

, "Manage list email options like mailing lists"
: "Bearbeitung von Gruppenoptionen (z.B. Mailinglisten)"

, "Relation, Relations"
: [
  ""
 ,""

]
, "Search for users ..."
: "Suche nach Benutzern ..."

, "Search for Contacts ..."
: "Suche nach Kontakten ..."

, "Tags"
: "Tags"

, "Name"
: "Name"

, "Member E-Mails"
: "Mitglieder E-Mails"

, "System Group"
: "Systemgruppe"

, "Group"
: "Gruppe"

, "Mailing List"
: "E-Mail-Verteiler"

, "This group is a mailing list"
: "Diese Gruppe ist ein E-Mail-Verteiler"

, "Keep copy of group mails"
: "Kopie der Gruppenmails behalten"

, "Forward external mails"
: "Externe E-Mails weiterleiten"

, "Only forward member mails"
: "Nur E-Mails von Gruppenmitgliedern weiterleiten"

, "Only forward to system email accounts"
: "E-Mails nur an Nutzer mit Systemkonto verteilen"

, "Select record to see its details"
: "Eintrag auswählen um Details zu sehen"

, "This module visualises hierarchically depended relations between records of different types."
: "Dieses Modul visualisiert hierarchisch abhängige Beziehungen zwischen Einträgen verschiedener Typen. "

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: "Hierarchisch abhängige Beziehungen werden von einigen Datentypen wie z.B. Benutzern und Gruppen automatisch  erstellt. Sie können aber auch manuell mit den entsprechenden Verknüpfungstypen erzeugt werden."

, "Loading Structure data..."
: "Lade Strukturdaten..."

, "List Roles"
: "Gruppenfunktionen"

, "Remove Member"
: "Mitglied entfernen"

, "Search for system groups ..."
: "Suche nach Systemgruppen ..."

, "Search for groups ..."
: "Suche nach Gruppen ..."

, "Map"
: "Karte"

, "Personal Information"
: "Persönliche Informationen"

, "Contact Information"
: "Kontakt-Informationen"

, "E-Mail (private)"
: "E-Mail (privat)"

, "Company Address"
: "Geschäftliche Anschrift"

, "Postal Code"
: "Postleitzahl"

, "Enter description"
: "Bitte geben Sie eine Beschreibung an"

, "Parse address"
: "Adresse einlesen"

, "Print contact"
: "Kontakt drucken"

, "Paste address"
: "Adresse einfügen"

, "Please paste an address or a URI to a vcard that should be parsed:"
: "Bitte fügen Sie eine Adresse oder URI zu einer vcard ein, die eingelesen werden soll:"

, "Failed to parse address!"
: "Einlesen der Adresse fehlgeschlagen!"

, "The address could not be read."
: "Die Adresse konnte nicht gelesen werden."

, "End token mode"
: "Beende Merkmalsmodus"

, "New Contact"
: "Neuer Kontakt"

, "ID"
: "ID"

, "Structure, Structures"
: [
  "Struktur"
 ,"Strukturen"

]
, "Resources"
: "Ressourcen"

, "Business"
: "Geschäft"

, "Private"
: "Privat"

, "Member of List"
: "Gruppenmitglied"

, "Related to"
: "Verknüpft mit"

, "Customfields"
: "Zusatzfelder"

, "List Functions"
: "Gruppenfunktionen"

, "Lists"
: "Gruppen"

, "Select list"
: "Gruppe auswählen"

, "Import contacts"
: "Kontakte importieren"

, "Contact of a user account"
: "Kontakt eines Nutzerkontos"

, "No name"
: "Kein Name"

, "Not set"
: "Nicht gesetzt"

, "Contact Image"
: "Kontaktbild"

, "Attachments"
: "Anhänge"

, "Street (Company Address)"
: "Straße (Geschäftliche Anschrift)"

, "Street 2 (Company Address)"
: "Straße 2 (Geschäftliche Anschrift)"

, "City (Company Address)"
: "Ort (Geschäftliche Anschrift)"

, "Region (Company Address)"
: "Bundesland (Geschäftliche Anschrift)"

, "Postal Code (Company Address)"
: "Postleitzahl (Geschäftliche Anschrift)"

, "Country (Company Address)"
: "Land (Geschäftliche Anschrift)"

, "Longitude (Company Address)"
: "Längengrad (Firmenadresse )"

, "Latitude (Company Address)"
: "Breitengrad (Firmenadresse )"

, "Street (Private Address)"
: "Straße (Private Anschrift)"

, "Street 2 (Private Address)"
: "Straße 2 (Private Anschrift)"

, "City (Private Address)"
: "Ort (Private Anschrift)"

, "Region (Private Address)"
: "Bundesland (Private Anschrift)"

, "Postal Code (Private Address)"
: "Postleitzahl (Private Anschrift)"

, "Country (Private Address)"
: "Land (Private Anschrift)"

, "Company Communication"
: "Firmenkommunikation"

, "Private Communication"
: "Privatkommunikation"

, "Web (private)"
: "Webseite (Privat)"

, "Contacts"
: "Kontakte"

, "Addressbooks"
: "Adressbücher"

, "User Account"
: "Benutzerkonto"

, "Quick Search"
: "Schnellsuche"

, "Last Modified Time"
: "Zuletzt geändert"

, "Last Modified By"
: "Zuletzt geändert von"

, "Creation Time"
: "Erstelldatum"

, "Created By"
: "Angelegt von"

, "Email Address, Email Addresses"
: [
  "E-mail Adresse"
 ,"E-mail Adressen"

]
, "Email Addresses"
: "E-mail Adressen"

, "Quick search"
: "Schnellsuche"

, "List Function, List Functions"
: [
  "Gruppenfunktion"
 ,"Gruppenfunktionen"

]
, "Industries"
: "Branchen"

, "Structures"
: "Strukturen"

, "CardDAV URL"
: "CardDAV URL"

, "List Information"
: "Gruppeninformationen"

, "System accounts only"
: "Nur Systembenutzer"

, "{0} must be given"
: "{0} muss gegeben sein"

, "Company address"
: "Firmenadresse"

, "Private address"
: "Privatadresse"

, "All contacts"
: "Alle Kontakte"

, "Default Addressbook"
: "Standard Adressbuch"

, "The default addressbook for new contacts"
: "Standard-Adressbuch für neue Kontakte"

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on addressbook startup"
: "Der Standard Favorit der beim öffnen des Adressbuches geladen wird"

, "Contacts ODS export configuration"
: "Kontakt ODS-Export Konfiguration"

, "Use this configuration for the contact ODS export."
: "Hiermit können Sie die zu verwendende Kontakt ODS-Export Konfiguration einstellen."

, "Contacts XLS export configuration"
: "Kontakt XLS-Export Konfiguration"

, "Use this configuration for the contact XLS export."
: "Hiermit können Sie die zu verwendende XLS-Export Konfiguration einstellen."

, "default"
: "Standard"

, "%s's personal addressbook"
: "%ss persönliches Adressbuch"

, "This contact has been automatically added by the system as an event attender"
: "Dieser Kontakt wurde automatisch vom System als Termin Teilnehmer hinzugefügt."

, "All Contacts"
: "Alle Kontakte"


























, "Addressbook"
: "Adressbuch"

, "Contact"
: "Kontakt"

, "Industry"
: "Branche"

, "List"
: "Gruppe"

, "Relation"
: ""

, "Structure"
: "Struktur"

, "Email Address"
: "E-mail Adresse"

, "List Function"
: "Gruppenfunktion"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
